@@ -16,8 +16,8 @@
 """
 import six
 import cfnlint.helpers
-from cfnlint import CloudFormationLintRule
-from cfnlint import RuleMatch
+from cfnlint.rules import CloudFormationLintRule
+from cfnlint.rules import RuleMatch
 
 
 class InstanceSize(CloudFormationLintRule):
